Index: src/x64/macro-assembler-x64.h |
diff --git a/src/x64/macro-assembler-x64.h b/src/x64/macro-assembler-x64.h |
index 01a449f6098967094accb6d6edcdf8e8b29f82ed..e1538ad48a6e6761440f4f553924b2f44a27b937 100644 |
--- a/src/x64/macro-assembler-x64.h |
+++ b/src/x64/macro-assembler-x64.h |
@@ -808,7 +808,7 @@ class MacroAssembler: public Assembler { |
// cvtsi2sd instruction only writes to the low 64-bit of dst register, which |
// hinders register renaming and makes dependence chains longer. So we use |
// xorps to clear the dst register before cvtsi2sd to solve this issue. |
void Cvtlsi2sd(XMMRegister dst, Register src); |
void Cvtlsi2sd(XMMRegister dst, const Operand& src); |
@@ -905,6 +905,8 @@ class MacroAssembler: public Assembler { |
void Movq(XMMRegister dst, Register src); |
void Movq(Register dst, XMMRegister src); |
+ void Xorpd(XMMRegister dst, XMMRegister src); |
+ |
// Control Flow |
void Jump(Address destination, RelocInfo::Mode rmode); |
void Jump(ExternalReference ext); |
@@ -808,7 +808,7 @@ class MacroAssembler: public Assembler { |
// cvtsi2sd instruction only writes to the low 64-bit of dst register, which |
// hinders register renaming and makes dependence chains longer. So we use |
- // xorps to clear the dst register before cvtsi2sd to solve this issue. |
+ // xorpd to clear the dst register before cvtsi2sd to solve this issue. |
void Cvtlsi2sd(XMMRegister dst, Register src); |
void Cvtlsi2sd(XMMRegister dst, const Operand& src); |